@@ -77,7 +77,7 @@ bool ClassImport::importFiles(const QStringList& fileNames)
             result = false;
         processedFilesCount++;
     }
-    umldoc->writeToStatusBar(i18nc("ready to status bar", "Ready."));
+    umldoc->writeToStatusBar(result ? i18nc("ready to status bar", "Ready.") : i18nc("failed to status bar", "Failed."));
     return result;
 }
 
