@@ -168,8 +168,7 @@ struct charLiteral :
         definition(charLiteral const& self) {
             main =
                 (!ch_p('L') >> ch_p('\'')
-                 >> *((anychar_p - '\'' - '\\')
-                      | (ch_p('\\') >> (ch_p('\'') | '\\')))
+                 >> *((anychar_p - '\'' - '\\') | gr_escapeSequence)
                  >> '\'')
                 [ self.result_ = construct_<Token>(Token_char_literal, arg1, arg2)];
         }
@@ -579,16 +578,23 @@ void PreprocessLexer::output(CharIterator p_first, CharIterator p_last)
         m_preprocessedString += *p_first;
 }
 
-void PreprocessLexer::preprocess()
+bool PreprocessLexer::preprocess()
 {
     for (;;) {
+        Position start = currentPosition();
         nextLine();
+        if (currentPosition() == start) {
+            uError() << "failed to preprocess file" << start;
+            return false;
+        }
+
         if (m_source.currentChar().isNull())
             break;
     }
 
     Token tk = m_source.createToken(Token_eof, m_source.get_ptr());
     m_preprocessedString += tk.text();
+    return true;
 }
 
 void PreprocessLexer::addSkipWord(const QString& word, SkipType skipType, const QString& str)
@@ -770,7 +776,13 @@ void PreprocessLexer::processDefine()
             Token tk;
             nextToken(tk);
 
-            if (tk.type() != -1) {
+            if (tk == '#') {
+                nextToken(tk);
+                if (tk.type() != -1) {
+                    body += '"' + tk.text() + '"';
+                }
+            }
+            else if (tk.type() != -1) {
                 QString s = tk.text();
                 body += s;
             }
@@ -959,6 +971,14 @@ int PreprocessLexer::macroExpression()
     return macroLogicalOr();
 }
 
+PreprocessLexer::CharRule gr_simpleEscapeSequence = (ch_p('\\') >> (ch_p('\\') | '"' | 'a' | 'b' | 'f' | 'n' | 'r' | 't' | 'v' | '0' ));
+PreprocessLexer::CharRule gr_octalDigit = (ch_p('0') | '1' | '2' | '3' | '4' | '5' | '6' | '7');
+PreprocessLexer::CharRule gr_digit = (ch_p('0') | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9');
+PreprocessLexer::CharRule gr_hexDigit = (gr_digit | 'A' | 'B' | 'C' | 'D' | 'E' | 'F' | 'a' | 'b' | 'c' | 'd' | 'e' | 'f');
+PreprocessLexer::CharRule gr_octalEscapeSequence = (ch_p('\\') >> gr_octalDigit >> *gr_octalDigit);
+PreprocessLexer::CharRule gr_hexEscapeSequence = (ch_p('\\') >> ch_p('x') >> gr_hexDigit >> gr_hexDigit);
+PreprocessLexer::CharRule gr_escapeSequence = gr_simpleEscapeSequence | gr_octalEscapeSequence | gr_hexEscapeSequence;
+
 // *IMPORTANT* please, don't include preprocesslexer.moc here, because
 // PreprocessLexer isn't a QObject class!!  if you have problem while
 // recompiling try to remove cppsupport/.deps, cppsupport/Makefile.in
