@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2011                                               *
+ *   copyright (C) 2004-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 #include "floatingdashlinewidget.h"
 #include "objectwidget.h"
 #include "uml.h"
-#include "umlscene.h"
+#include "umlview.h"
 #include "umlwidget.h"
 
 /**
@@ -38,7 +38,7 @@ ToolBarState::~ToolBarState()
  */
 void ToolBarState::init()
 {
-    m_pUMLScene->viewport()->setMouseTracking(false);
+    m_pUMLScene->view()->viewport()->setMouseTracking(false);
     m_pMouseEvent = 0;
     m_currentWidget = 0;
     m_currentAssociation = 0;
@@ -77,23 +77,23 @@ void ToolBarState::mousePress(UMLSceneMouseEvent* ome)
 {
     setMouseEvent(ome, QEvent::MouseButtonPress);
 
-    m_pUMLScene->viewport()->setMouseTracking(true);
+    m_pUMLScene->view()->viewport()->setMouseTracking(true);
 
     //TODO Doesn't another way of emiting the signal exist? A method only for
     //that seems a bit dirty.
     m_pUMLScene->emitRemovePopupMenu();
 
     // TODO: Check who needs this.
-    m_pUMLScene->setPos(m_pMouseEvent->pos());
+    m_pUMLScene->setPos(m_pMouseEvent->scenePos());
 
     //TODO check why
     m_pUMLScene->setPaste(false);
 
     setCurrentElement();
 
-    if (getCurrentWidget()) {
+    if (currentWidget()) {
         mousePressWidget();
-    } else if (getCurrentAssociation()) {
+    } else if (currentAssociation()) {
         mousePressAssociation();
     } else {
         mousePressEmpty();
@@ -115,14 +115,14 @@ void ToolBarState::mouseRelease(UMLSceneMouseEvent* ome)
 
     // Set the position of the mouse
     // TODO, should only be available in this state?
-    m_pUMLScene->setPos(m_pMouseEvent->pos());
+    m_pUMLScene->setPos(m_pMouseEvent->scenePos());
 
-    m_pUMLScene->viewport()->setMouseTracking(false);
+    m_pUMLScene->view()->viewport()->setMouseTracking(false);
 
-    if (getCurrentWidget()) {
+    if (currentWidget()) {
         mouseReleaseWidget();
         setCurrentWidget(0);
-    } else if (getCurrentAssociation()) {
+    } else if (currentAssociation()) {
         mouseReleaseAssociation();
         setCurrentAssociation(0);
     } else {
@@ -146,8 +146,8 @@ void ToolBarState::mouseDoubleClick(UMLSceneMouseEvent* ome)
 {
     setMouseEvent(ome, QEvent::MouseButtonDblClick);
 
-    UMLWidget* currentWidget = m_pUMLScene->widgetAt(m_pMouseEvent->pos());
-    AssociationWidget* currentAssociation = getAssociationAt(m_pMouseEvent->pos());
+    UMLWidget* currentWidget = m_pUMLScene->widgetAt(m_pMouseEvent->scenePos());
+    AssociationWidget* currentAssociation = associationAt(m_pMouseEvent->scenePos());
     if (currentWidget) {
         setCurrentWidget(currentWidget);
         mouseDoubleClickWidget();
@@ -178,9 +178,9 @@ void ToolBarState::mouseMove(UMLSceneMouseEvent* ome)
 {
     setMouseEvent(ome, QEvent::MouseMove);
 
-    if (getCurrentWidget()) {
+    if (currentWidget()) {
         mouseMoveWidget();
-    } else if (getCurrentAssociation()) {
+    } else if (currentAssociation()) {
         mouseMoveAssociation();
     } else {
         mouseMoveEmpty();
@@ -189,18 +189,18 @@ void ToolBarState::mouseMove(UMLSceneMouseEvent* ome)
     //Scrolls the view
     int vx = ome->x();
     int vy = ome->y();
-    int contsX = m_pUMLScene->contentsX();
-    int contsY = m_pUMLScene->contentsY();
-    int visw = m_pUMLScene->visibleWidth();
-    int vish = m_pUMLScene->visibleHeight();
+    int contsX = m_pUMLScene->view()->contentsX();
+    int contsY = m_pUMLScene->view()->contentsY();
+    int visw = m_pUMLScene->view()->visibleWidth();
+    int vish = m_pUMLScene->view()->visibleHeight();
     int dtr = visw - (vx-contsX);
     int dtb = vish - (vy-contsY);
     int dtt =  (vy-contsY);
     int dtl =  (vx-contsX);
-    if (dtr < 30) m_pUMLScene->scrollBy(30-dtr,0);
-    if (dtb < 30) m_pUMLScene->scrollBy(0,30-dtb);
-    if (dtl < 30) m_pUMLScene->scrollBy(-(30-dtl),0);
-    if (dtt < 30) m_pUMLScene->scrollBy(0,-(30-dtt));
+    if (dtr < 30) m_pUMLScene->view()->scrollBy(30-dtr,0);
+    if (dtb < 30) m_pUMLScene->view()->scrollBy(0,30-dtb);
+    if (dtl < 30) m_pUMLScene->view()->scrollBy(-(30-dtl),0);
+    if (dtt < 30) m_pUMLScene->view()->scrollBy(0,-(30-dtt));
 }
 
 /**
@@ -211,7 +211,7 @@ void ToolBarState::mouseMove(UMLSceneMouseEvent* ome)
  */
 void ToolBarState::slotAssociationRemoved(AssociationWidget* association)
 {
-    if (association == getCurrentAssociation()) {
+    if (association == currentAssociation()) {
         setCurrentAssociation(0);
     }
 }
@@ -224,7 +224,7 @@ void ToolBarState::slotAssociationRemoved(AssociationWidget* association)
  */
 void ToolBarState::slotWidgetRemoved(UMLWidget* widget)
 {
-    if (widget == getCurrentWidget()) {
+    if (widget == currentWidget()) {
         setCurrentWidget(0);
     }
 }
@@ -239,9 +239,9 @@ void ToolBarState::slotWidgetRemoved(UMLWidget* widget)
  */
 ToolBarState::ToolBarState(UMLScene *umlScene)
   : QObject(umlScene),
-    m_pUMLScene(umlScene)
+    m_pUMLScene(umlScene),
+    m_pMouseEvent(0)
 {
-    m_pMouseEvent = NULL;
     init();
 }
 
@@ -256,7 +256,7 @@ ToolBarState::ToolBarState(UMLScene *umlScene)
 void ToolBarState::setCurrentElement()
 {
     // Check associations.
-    AssociationWidget* association = getAssociationAt(m_pMouseEvent->pos());
+    AssociationWidget* association = associationAt(m_pMouseEvent->scenePos());
     if (association) {
         setCurrentAssociation(association);
         return;
@@ -264,27 +264,27 @@ void ToolBarState::setCurrentElement()
 
     // Check messages.
     //TODO check why message widgets are treated different
-    MessageWidget* message = getMessageAt(m_pMouseEvent->pos());
+    MessageWidget* message = messageAt(m_pMouseEvent->scenePos());
     if (message) {
         setCurrentWidget(message);
         return;
     }
 
     //TODO check why message widgets are treated different
-    FloatingDashLineWidget* floatingline = getFloatingLineAt(m_pMouseEvent->pos());
+    FloatingDashLineWidget* floatingline = floatingLineAt(m_pMouseEvent->scenePos());
     if (floatingline) {
         setCurrentWidget(floatingline);
         return;
     }
 
-    ObjectWidget* objectWidgetLine = m_pUMLScene->onWidgetDestructionBox(m_pMouseEvent->pos());
+    ObjectWidget* objectWidgetLine = m_pUMLScene->onWidgetDestructionBox(m_pMouseEvent->scenePos());
     if (objectWidgetLine) {
         setCurrentWidget(objectWidgetLine);
         return;
     }
 
     // Check widgets.
-    UMLWidget *widget = m_pUMLScene->widgetAt(m_pMouseEvent->pos());
+    UMLWidget *widget = m_pUMLScene->widgetAt(m_pMouseEvent->scenePos());
     if (widget) {
         setCurrentWidget(widget);
         return;
@@ -408,7 +408,7 @@ void ToolBarState::changeTool()
  *
  * @return The widget currently in use.
  */
-UMLWidget* ToolBarState::getCurrentWidget() const
+UMLWidget* ToolBarState::currentWidget() const
 {
     return m_currentWidget;
 }
@@ -420,11 +420,11 @@ UMLWidget* ToolBarState::getCurrentWidget() const
  * Default implementation is set the specified widget, although this
  * behaviour can be overridden in subclasses if needed.
  *
- * @param currentWidget The widget to be set.
+ * @param widget The widget to be set.
  */
-void ToolBarState::setCurrentWidget(UMLWidget* currentWidget)
+void ToolBarState::setCurrentWidget(UMLWidget* widget)
 {
-    m_currentWidget = currentWidget;
+    m_currentWidget = widget;
 }
 
 /**
@@ -432,7 +432,7 @@ void ToolBarState::setCurrentWidget(UMLWidget* currentWidget)
  *
  * @return The association currently in use.
  */
-AssociationWidget* ToolBarState::getCurrentAssociation() const
+AssociationWidget* ToolBarState::currentAssociation() const
 {
     return m_currentAssociation;
 }
@@ -444,11 +444,11 @@ AssociationWidget* ToolBarState::getCurrentAssociation() const
  * Default implementation is set the specified association, although this
  * behaviour can be overridden in subclasses if needed.
  *
- * @param currentAssociation The association to be set.
+ * @param association The association to be set.
  */
-void ToolBarState::setCurrentAssociation(AssociationWidget* currentAssociation)
+void ToolBarState::setCurrentAssociation(AssociationWidget* association)
 {
-    m_currentAssociation = currentAssociation;
+    m_currentAssociation = association;
 }
 
 /**
@@ -463,7 +463,7 @@ void ToolBarState::setMouseEvent(UMLSceneMouseEvent* ome, const QEvent::Type &ty
 {
     delete m_pMouseEvent;
 
-    m_pMouseEvent = new UMLSceneMouseEvent(type, m_pUMLScene->inverseWorldMatrix().map(ome->pos()),
+    m_pMouseEvent = new UMLSceneMouseEvent(type, m_pUMLScene->view()->inverseWorldMatrix().map(ome->pos()),
                                     ome->button(),ome->buttons(),ome->modifiers());
 }
 
@@ -476,14 +476,13 @@ void ToolBarState::setMouseEvent(UMLSceneMouseEvent* ome, const QEvent::Type &ty
  * @return The MessageWidget at the specified position, or null if there is none.
  * @todo Better handling for messages at the same point
  */
-MessageWidget* ToolBarState::getMessageAt(const QPoint& pos)
+MessageWidget* ToolBarState::messageAt(const UMLScenePoint& pos)
 {
-    foreach (  MessageWidget* message, m_pUMLScene->getMessageList() ) {
+    foreach (MessageWidget* message, m_pUMLScene->messageList()) {
         if (message->isVisible() && message->onWidget(pos)) {
             return message;
         }
     }
-
     return 0;
 }
 
@@ -495,14 +494,13 @@ MessageWidget* ToolBarState::getMessageAt(const QPoint& pos)
  * @return The AssociationWidget at the specified position, or null if there is none.
  * @todo Better handling for associations at the same point
  */
-AssociationWidget* ToolBarState::getAssociationAt(const QPoint& pos)
+AssociationWidget* ToolBarState::associationAt(const UMLScenePoint& pos)
 {
-    foreach ( AssociationWidget* association, m_pUMLScene->getAssociationList() ) {
+    foreach (AssociationWidget* association, m_pUMLScene->associationList()) {
         if (association->onAssociation(pos)) {
             return association;
         }
     }
-
     return 0;
 }
 
@@ -513,11 +511,11 @@ AssociationWidget* ToolBarState::getAssociationAt(const QPoint& pos)
  * @param pos The position to get the floatingLine.
  * @return The MessageWidget at the specified position, or null if there is none.
  */
-FloatingDashLineWidget* ToolBarState::getFloatingLineAt(const QPoint& pos)
+FloatingDashLineWidget* ToolBarState::floatingLineAt(const UMLScenePoint& pos)
 {
     FloatingDashLineWidget* floatingline = 0;
 
-    foreach ( UMLWidget* widget, m_pUMLScene->getWidgetList() ) {
+    foreach (UMLWidget* widget, m_pUMLScene->widgetList()) {
         if (widget->baseType() == WidgetBase::wt_FloatingDashLine){
             if (dynamic_cast<FloatingDashLineWidget*>(widget)->onLine(pos)) {
                 floatingline = dynamic_cast<FloatingDashLineWidget*>(widget);
@@ -529,4 +527,3 @@ FloatingDashLineWidget* ToolBarState::getFloatingLineAt(const QPoint& pos)
 }
 
 #include "toolbarstate.moc"
-
